# Changelog

## [0.5.0a1](https://github.com/OpenVoiceOS/ovos-utils/tree/0.5.0a1) (2024-11-20)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/0.4.1...0.5.0a1)

**Merged pull requests:**

- feat:oauth utils to ovos-utils and deprecate backend-client [\#301](https://github.com/OpenVoiceOS/ovos-utils/pull/301) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
